pytilities.geometry._rectanglebase — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry._rectanglebase

class `pytilities.geometry._rectanglebase.` `_RectangleBase`(*args, **kwargs)
  `_RectangleBase__inflate_number`(n)
  `_RectangleBase__inflate_vector`(v)
  `_RectangleBase__set_bounds_numbers`(left, top, right, bottom)
  `_RectangleBase__set_bounds_points`(top_left, bottom_right)
  `__copy__`(*args, **kwargs)
  `__delattr__`(*args, **kwargs)
  `__getattribute__`(*args, **kwargs)
  `__repr__`(*args, **kwargs)
  `__setattr__`(*args, **kwargs)
  `__str__`(*args, **kwargs)
  `contains`(*args, **kwargs)
  `copy`(*args, **kwargs)
  `inflate`(*args, **kwargs)
  `move_by`(*args, **kwargs)
  `move_to`(*args, **kwargs)
  `overlaps`(*args, **kwargs)
  `__weakref__`

    list of weak references to the object (if defined)

  `bottom`

    Read-write, bottom edge of rectangle

  `bottom_left`

    Read-write, bottom-left corner :: bound Vector

  `bottom_right`

    Read-write, bottom-right corner :: bound Vector

  `bounds`

    Read-write, all rectangle coordinates

    Returns (left, top, right, bottom)

    Overloaded, set parameters:

    A : | left :: float | int top :: float | int right :: float | int bottom :: float | int
    B : | top_left :: Vector bottom_right :: Vector

  `center`

    Read-write, center of the rectangle :: bound Vector

    Changing the center does not change the size.

  `left`

    Read-write, left edge of rectangle

  `right`

    Read-write, right edge of rectangle

  `size`

    Read-write, size of the rectangle :: bound Vector

  `top`

    Read-write, top edge of rectangle

  `top_left`

    Read-write, top-left corner :: bound Vector

  `top_right`

    Read-write, top-right corner :: bound Vector

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »